@@ -36,7 +36,6 @@
 #define ENABLE_KEY_TIMEOUT 1000
 
 
-
 static gboolean
 enable_fullscreen(gpointer data)
 {
@@ -734,6 +733,28 @@ top_changed(GObject * self, GParamSpec * property_param, gpointer data)
     }
 }
 
+gboolean take_screen_shot(gpointer widget)
+{
+	GtkWidget *window = (GtkWidget *)widget;
+        gchar *filename = NULL;
+        gchar *service = g_strconcat(game_get_service(), ".pvr", NULL);
+
+        filename = g_build_filename((const gchar*)"/home/user/.cache/launch/", service,
+		                                           NULL);
+	if(FALSE == g_file_test(filename, G_FILE_TEST_EXISTS)) {
+		hildon_gtk_window_take_screenshot(GTK_WINDOW(window), TRUE);
+	}
+
+	return FALSE;	
+
+}
+
+void
+game_get_screenshot(GtkWidget * widget, GdkEventKey * event, gpointer data)
+{
+	g_idle_add((GSourceFunc)(take_screen_shot), (gpointer)(widget));
+}
+
 void
 game_play_cb(GtkWidget * widget, gpointer data)
 {
